@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.106-5-ga6331d9
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.107-5-g38ecc1d
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.107';
+our $VERSION = '0.108';
 
 use Moose;
 with
@@ -210,7 +210,7 @@ sub configure
 
         qw(MetaYAML MetaJSON Readme Manifest),
         [ 'License'             => { ':version' => '5.038', filename => $self->licence } ],
-        [ 'GenerateFile::ShareDir' => 'generate CONTRIBUTING' => { -dist => 'Dist-Zilla-PluginBundle-Author-ETHER', -filename => 'CONTRIBUTING', has_xs => $has_xs } ],
+        [ 'GenerateFile::FromShareDir' => 'generate CONTRIBUTING' => { -dist => 'Dist-Zilla-PluginBundle-Author-ETHER', -filename => 'CONTRIBUTING', has_xs => $has_xs } ],
         [ 'InstallGuide'        => { ':version' => '1.200005' } ],
 
         [ 'Test::Compile'       => { ':version' => '2.039', bail_out_on_fail => 1, xt_mode => 1,
@@ -446,7 +446,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.107
+version 0.108
 
 =head1 SYNOPSIS
 
@@ -514,7 +514,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     :version = 5.038
     filename = LICENCE  ; for distributions where I have authority
 
-    [GenerateFile::ShareDir / generate CONTRIBUTING]
+    [GenerateFile::FromShareDir / generate CONTRIBUTING]
     -dist = Dist-Zilla-PluginBundle-Author-ETHER
     -filename = CONTRIBUTING
     has_xs = <dynamically-determined flag>
