@@ -4,7 +4,7 @@ package Pod::Weaver::PluginBundle::Author::ETHER;
 # ABSTRACT: A plugin bundle for pod woven by ETHER
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.107';
+our $VERSION = '0.108';
 
 use namespace::autoclean -also => ['_exp'];
 use Pod::Weaver::Config::Assembler;
@@ -62,7 +62,7 @@ sub configure
     $distmeta->{resources}{x_MailingList} ? 'There is also a mailing list available for users of this distribution, at' . "\nL<" . $distmeta->{resources}{x_MailingList} . '>.' : (),
 
     $distmeta->{resources}{x_IRC}
-        ? 'There is also an irc channel available for users of this distribution, at' . "\n" . $distmeta->{resources}{x_IRC} . '.'
+        ? 'There is also an irc channel available for users of this distribution, at' . "\nL<" . $distmeta->{resources}{x_IRC} . '>.'
         : (),
 
     ($distmeta->{x_authority} // '') eq 'cpan:ETHER'
@@ -167,7 +167,7 @@ Pod::Weaver::PluginBundle::Author::ETHER - A plugin bundle for pod woven by ETHE
 
 =head1 VERSION
 
-version 0.107
+version 0.108
 
 =head1 SYNOPSIS
 
