@@ -3,7 +3,9 @@ use warnings;
 package {{ $name }};
 # ABSTRACT: ...
 # KEYWORDS: ...
-# vim: set ts=8 sw=4 tw=78 et :
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
+
+our $VERSION = '{{ $dist->version }}';
 
 {{
     ($zilla_plugin) = ($name =~ /^Dist::Zilla::Plugin::(.+)$/g);
@@ -20,7 +22,8 @@ around dump_config => sub
     my $config = $self->$orig;
 
     $config->{+__PACKAGE__} = {
-        ...
+        ...,
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
 
     return $config;
@@ -58,14 +61,6 @@ SYNOPSIS
 
 ...
 
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name={{ $dist->name }}>
-(or L<bug-{{ $dist->name }}@rt.cpan.org|mailto:bug-{{ $dist->name }}@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 ACKNOWLEDGEMENTS
 
 ...
